@@ -27,7 +27,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.23';
+our $VERSION = '2.24';
 
 sub db {
   my $self = shift;
@@ -108,9 +108,17 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   use Mojo::Pg;
 
-  # Create a table
+  # Select the server version
   my $pg = Mojo::Pg->new('postgresql://postgres@/test');
-  $pg->db->query('create table names (id serial primary key, name text)');
+  say $pg->db->query('select version() as version')->hash->{version};
+
+  # Use migrations to create a table
+  $pg->migrations->name('my_names_app')->from_string(<<EOF)->migrate;
+  -- 1 up
+  create table names (id serial primary key, name text);
+  -- 1 down
+  drop table names;
+  EOF
 
   # Insert a few rows
   my $db = $pg->db;
@@ -202,6 +210,14 @@ gracefully by holding on to them only for short amounts of time.
 
   app->start;
 
+In this example application, we create a C<pg> helper to store a L<Mojo::Pg>
+object. Our action calls that helper and uses the method L<Mojo::Pg/"db"> to
+dequeue a L<Mojo::Pg::Database> object from the connection pool. Then we use the
+method L<Mojo::Pg::Database/"query"> to execute an
+L<SQL|http://www.postgresql.org/docs/current/static/sql.html> statement, which
+returns a L<Mojo::Pg::Results> object. And finally we call the method
+L<Mojo::Pg::Results/"hash"> to retrieve the first row as a hash reference.
+
 While all I/O operations are performed blocking, you can wait for long running
 queries asynchronously, allowing the L<Mojo::IOLoop> event loop to perform
 other tasks in the meantime. Since database connections usually have a very low
@@ -347,8 +363,11 @@ efficiently, by sharing a single database connection with many consumers.
 Schema search path assigned to all new connections.
 
   # Isolate tests and avoid race conditions when running them in parallel
+  $pg->db->query('drop schema if exists test_one cascade');
+  $pg->db->query('create schema test_one');
   $pg->search_path(['test_one']);
-  $pg->migrations->migrate(0)->migrate;
+  ...
+  $pg->db->query('drop schema test_one cascade');
 
 =head2 username
 
@@ -451,7 +470,7 @@ Hernan Lopes
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2016, Sebastian Riedel.
+Copyright (C) 2014-2016, Sebastian Riedel and others.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
